@@ -601,7 +601,10 @@ namespace Microsoft.Boogie.SMTLib
         String specialValue = resp.Arguments[0].ToString();
         int expSize = int.Parse(resp.Arguments[1].ToString());
         int sigSize = int.Parse(resp.Arguments[2].ToString());
-        return new BaseTypes.BigFloat(specialValue, sigSize, expSize);
+        if (BaseTypes.BigFloat.TryCreateSpecialFromString(specialValue, sigSize, expSize, out var result)) {
+          return result;
+        }
+        throw new VCExprEvaluationException();
       }
 
       var ary = ParseArrayFromProverResponse(resp);
